==> public-sdk-2.0.30-sources.jar: com/voxeet/sdk/json/ConferenceStats.java <==
package com.voxeet.sdk.json;

import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.voxeet.sdk.core.preferences.VoxeetPreferences;

import java.util.Map;

/**
 * Note : this class is parsed by Gson due to an issue with Jackson with
 * HashMap : String -> HashMap : String -> Infos
 */

@JsonIgnoreProperties(ignoreUnknown = true)
@JsonTypeName(EventNames.CONFERENCE_STATS)
public class ConferenceStats extends Event {
    private String conference_id;

    private Map<String, Map<String, Infos>> participantStats;

    public String getConference_id() {
        return conference_id;
    }

    @Nullable
    public Map<String, Map<String, Infos>> getParticipantStats() {
        return participantStats;
    }

    public float getScore(@NonNull String userId) {
        String ownUserId = VoxeetPreferences.id();

        return getScore(ownUserId, userId);
    }

    public float getScore(@NonNull String fromUserIdPoV, @NonNull String userId) {
        float score = 0;
        if (participantStats.containsKey(fromUserIdPoV)) {
            Map<String, Infos> map = participantStats.get(fromUserIdPoV);
            if (null != map && map.containsKey(userId)) {
                Infos infos = map.get(userId);
                if (null != infos) {
                    for (Stats stats : infos.stats)
                        score += stats.score;
                    score /= Math.max(1, infos.stats.length);
                }
            }
        }
        return score;
    }

    @Nullable
    public Infos getStats(@NonNull String userId) {
        if (participantStats.containsKey(userId)) {
            Map<String, Infos> map = participantStats.get(userId);
            if (null != map && map.containsKey(userId)) {
                return map.get(userId);
            }
        }
        return null;
    }

    @Override
    public String getType() {
        return EventNames.CONFERENCE_STATS;
    }

    @JsonIgnoreProperties(ignoreUnknown = true)
    public static class Infos {

        public Infos() {

        }

        public Stats[] stats;
        public boolean master;
        public long estBitrate;
        public long stunRtt;
    }

    @JsonIgnoreProperties(ignoreUnknown = true)
    public static class Stats {

        public Stats() {

        }

        public String media;
        public float score;
        public long ssrc;
        public String lastPkt;
        public String firstPkt;
        public double jitter;
        public long lostPkt;
        public double fracLostPkt;
        public long recvBitrate;
        public long recvPkt;
        public long recvOct;
        public int audioLevel;
    }
}

==> public-sdk-2.0.71.2-sources.jar: com/voxeet/sdk/json/ConferenceStats.java <==
package com.voxeet.sdk.json;

import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.voxeet.sdk.core.preferences.VoxeetPreferences;
import com.voxeet.sdk.utils.Annotate;
import com.voxeet.sdk.utils.FromWebsocket;

import java.util.Map;

/**
 * Note : this class is parsed by Gson due to an issue with Jackson with
 * HashMap : String -> HashMap : String -> Infos
 */
@Annotate
@FromWebsocket
@JsonIgnoreProperties(ignoreUnknown = true)
@JsonTypeName(EventNames.CONFERENCE_STATS)
public class ConferenceStats extends Event {
    private String conference_id;

    private Map<String, Map<String, Infos>> participantStats;

    public String getConference_id() {
        return conference_id;
    }

    @Nullable
    public Map<String, Map<String, Infos>> getParticipantStats() {
        return participantStats;
    }

    public float getScore(@NonNull String userId) {
        String ownUserId = VoxeetPreferences.id();

        return getScore(ownUserId, userId);
    }

    public float getScore(@NonNull String fromUserIdPoV, @NonNull String userId) {
        float score = 0;
        if (participantStats.containsKey(fromUserIdPoV)) {
            Map<String, Infos> map = participantStats.get(fromUserIdPoV);
            if (null != map && map.containsKey(userId)) {
                Infos infos = map.get(userId);
                if (null != infos) {
                    for (Stats stats : infos.stats)
                        score += stats.score;
                    score /= Math.max(1, infos.stats.length);
                }
            }
        }
        return score;
    }

    @Nullable
    public Infos getStats(@NonNull String userId) {
        if (participantStats.containsKey(userId)) {
            Map<String, Infos> map = participantStats.get(userId);
            if (null != map && map.containsKey(userId)) {
                return map.get(userId);
            }
        }
        return null;
    }

    @Override
    public String getType() {
        return EventNames.CONFERENCE_STATS;
    }

    @JsonIgnoreProperties(ignoreUnknown = true)
    public static class Infos {

        public Infos() {

        }

        public Stats[] stats;
        public boolean master;
        public long estBitrate;
        public long stunRtt;
    }

    @JsonIgnoreProperties(ignoreUnknown = true)
    public static class Stats {

        public Stats() {

        }

        public String media;
        public float score;
        public long ssrc;
        public String lastPkt;
        public String firstPkt;
        public double jitter;
        public long lostPkt;
        public double fracLostPkt;
        public long recvBitrate;
        public long recvPkt;
        public long recvOct;
        public int audioLevel;
    }
}
